==> logtalk-3.88.0.tar.bz2: logtalk-3.88.0/examples/inlining/NOTES.md <==
---
jupyter:
  jupytext:
    text_representation:
      extension: .md
      format_name: markdown
      format_version: '1.1'
      jupytext_version: 1.16.6
  kernelspec:
    display_name: Logtalk
    language: logtalk
    name: logtalk_kernel
---

<!--
________________________________________________________________________

This file is part of Logtalk <https://logtalk.org/>  
SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>  
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
________________________________________________________________________
-->

# inlining

For a description of this example, please see the comments in the
`inlining.lgt` source file.

Start by loading the example:

```logtalk
logtalk_load(inlining(loader)).
```

Check that the between/3 predicate is inlined:

```logtalk
inlining::predicate_property(a(_,_), inline).
```

<!--
true.
-->

```logtalk
object_property(inlining, defines(a/2, Properties)).
```

<!--
Properties = [..., inline, ...].
-->

==> logtalk-3.90.1.tar.bz2: logtalk-3.90.1/examples/inlining/NOTES.md <==
---
jupyter:
  jupytext:
    text_representation:
      extension: .md
      format_name: markdown
      format_version: '1.3'
      jupytext_version: 1.16.7
  kernelspec:
    display_name: Logtalk
    language: logtalk
    name: logtalk_kernel
---

<!--
________________________________________________________________________

This file is part of Logtalk <https://logtalk.org/>  
SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>  
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
________________________________________________________________________
-->

# inlining

For a description of this example, please see the comments in the
`inlining.lgt` source file.

Print Logtalk, Prolog backend, and kernel versions (if running as a notebook):

```logtalk
%versions
```

Start by loading the example:

```logtalk
logtalk_load(inlining(loader)).
```

Confirm that the `between/3` predicate is inlined:

```logtalk
inlining::predicate_property(a(_,_), inline).
```

<!--
true.
-->

Query the definition properties of the inlined `a/2` predicate:

```logtalk
object_property(inlining, defines(a/2, Properties)).
```

<!--
Properties = [..., inline, ...].
-->
